///////////////////////////////////////////////////////
// Licensed Materials - Property of IBM
// 5724-W86, 5724-X63
// @ Copyright IBM Corporation 2010. All Rights Reserved.
// US Government Users Restricted Rights- Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.
///////////////////////////////////////////////////////


function createInputSchema()
{
    var result=PV.TextInputSchema(
        "ECIBRAS",
         {
              filePeriod: 900,
              multiFileJoin: true,
              holdGatePeriod: 10, 
              noNewInputLimit: 16, 
              parseURI: onParseURI
         },
         PV.DelimitedRecordSchema( // RecordSchema to skip the #FILE CREATED line
              "fileCreation",
              {
                   fieldSeparator:",",
                   recordSeparator:"\r",
                   maxOccurs:1,
                   onRead: onReadFileCreation
              },
              PV.StringFieldSchema("fileCreationDate")
         ),
         PV.DelimitedRecordSchema( // RecordSchema to retrieve the hostname
              "hostName",
              {
                   fieldSeparator:",",
                   recordSeparator:"\r",
                   maxOccurs:1,
                   onRead: onReadHostName
              },
              PV.StringFieldSchema("hostName")
         ),
         PV.DelimitedRecordSchema( // RecordSchema to retrieve the entire record (whole line)
              "record",
              {
                   hasHeaderRecord: true,
                   fieldSeparator:"\n",
                   recordSeparator:"\r",
                   maxOccurs:Infinity,
                   onRead: onReadRecord
              },
              PV.StringFieldSchema("fullRecord")
         )
    );
// if (LOG_DEBUG) result.traceTuples=true;
    return result;
}

function onParseURI(descriptor) {
    var name=descriptor.remoteName;

/*
 * ST - HYD_BBRAS.0-1269507372.counters
 * SR - HYD_CESR.0-1269507372.counters
*/

    var parts=name.split(".");

    var ftype=parts[0].split("_")[1];
    if(ftype == "BBRAS") {
    	descriptor.fileType="bbras";
    } else if (ftype == "CESR") {
    	descriptor.fileType="cesr";
    }

    var UTCTime=parts[1].split("-")[1];
    var ts=Number(UTCTime);
    ts = (ts / 900).toInt32() * 900;
    descriptor.timestamp = Date.fromUTCSeconds(ts);
}


/*
 * Placeholder function - do nothing
*/
function onReadFileCreation(record) {
}

/*
 * Function to keep a global hostname variable - for use in onReadRecord 
*/
function onReadHostName(record, descriptor) {
    	var hostname=record.hostName.split(" ")[1];
	descriptor.hostname = hostname;
//	record.schema.rootSchema.hostname = hostname;
}

/* onReadRecord function to do the following:
 * 1) Skip records that start with #profile-layout.
 * 2) Record Timestamp: The first field (delimited by comma) in the remaining records.
 *    A record is valid only if it is in number format, otherwise, ignore.
 * 3) Record file type: This will take the value from descriptor file type.
 * 4) Record host name: This will take the value from the onReadHostName function (hostname variable).
 * 5) Emit tuple.
*/

function onReadRecord(record, descriptor) {
    if(record.fullRecord == NULL) {
	PV.Logger.logDebug("E", "onReadRecord", "ECI-BRAS", "NULL record found");
    }

    // Ignore profile-layout line
    profile_Regex=new RegExp("^#profile-layout.*$");
    if(profile_Regex.exec(String(record.fullRecord))) {
	return;
    }

    var record_fields=record.fullRecord.split(",");
    if(isNaN(record_fields[1])) {
	return; // Skip if the record is not a number
    } else {
	record.timestamp=Number(record_fields[1]);
	record.fileType=descriptor.fileType;
	var channel = PV.channelNumber;
	var collector = PV.collectorNumber;
	record.hostName=descriptor.hostname + "_" + channel + "_" + collector;
//	PV.Logger.logDebug("I", "onReadRecord", "ECI-BRAS-TESTING", "fileType:" + record.fileType + " HostName:" + record.hostName);
    }	

    // Emit Tuple
    if(record.timestamp) {
	this.emitTuple(record);
    } else {
	PV.Logger.logDebug("E", "onReadRecord", "ECI-BRAS", "Invalid record timestamp");
	return;
    }
}

// END
